One_Interfaces
==============
Python bindings for One protobuf packages.

Supported File Formats
======================
Universal wheel file and source tar ball

Requirements
============
protobuf runtime

Usage
=====
pip install one_interfaces-<version>-py2.py3-none-any.whl
Add the module to the sys.path by either adding the module path to PYTHONPATH 
or copy one_interfaces.pth to the python site-packages directory.

Testing
=======

